@@ -1,6 +1,6 @@
 import numpy as np
-import cv2
 from PIL import Image
+import requests
 
 
 def load_image(path, resize_height, resize_width, gray, normalization):
@@ -15,6 +15,14 @@ def load_image(path, resize_height, resize_width, gray, normalization):
     return input_image
 
 
+def download_image(image_download_url):
+    image_download_response = requests.get(image_download_url)
+    if image_download_response.ok:
+        image = np.asarray(bytearray(image_download_response.content), dtype="uint8")
+        return image
+    return None
+
+
 def draw_rectangle(draw, points, color, width):
     draw.line([(points[0], points[1]), (points[2], points[1])], fill=color, width=width)
     draw.line([(points[2], points[1]), (points[2], points[3])], fill=color, width=width)
